<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/core/RUnit.cpp" line="+272"/>
        <source>None</source>
        <translation>Geen</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Inch</source>
        <translation>Inch</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Foot</source>
        <translation>Voet</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mile</source>
        <translation>Mile</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Millimeter</source>
        <translation>Millimeter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Centimeter</source>
        <translation>Centimeter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Meter</source>
        <translation>Meter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Kilometer</source>
        <translation>Kilometer</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Microinch</source>
        <translation>Microinch</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mil</source>
        <translation>Mil</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Yard</source>
        <translation>Yard</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Angstrom</source>
        <translation>Angstrom</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Nanometer</source>
        <translation>Nanometer</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Micron</source>
        <translation>Micron</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decimeter</source>
        <translation>Decimeter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decameter</source>
        <translation>Decameter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Hectometer</source>
        <translation>Hectometer</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Gigameter</source>
        <translation>Gigameter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Astro</source>
        <translation>Astro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Lightyear</source>
        <translation>Lichtjaar</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Parsec</source>
        <translation>Parsec</translation>
    </message>
</context>
<context>
    <name>RColor</name>
    <message>
        <location filename="../src/core/RColor.cpp" line="+340"/>
        <source>By Layer</source>
        <translation>Door laag bepaald</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>Door blok bepaald</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Red</source>
        <translation>Rood</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Green</source>
        <translation>Groen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Blue</source>
        <translation>Blauw</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Cyan</source>
        <translation>Cyaan</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Magenta</source>
        <translation>Magenta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Yellow</source>
        <translation>Geel</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Orange</source>
        <translation>Oranje</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Red</source>
        <translation>Donkerrood</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Green</source>
        <translation>Donkergroen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Blue</source>
        <translation>Donkerblauw</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Cyan</source>
        <translation>Donkercyaan</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Magenta</source>
        <translation>Donkermagenta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Yellow</source>
        <translation>Donkergeel</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Black</source>
        <translation>Zwart</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gray</source>
        <translation>Grijs</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Light Gray</source>
        <translation>Lichtgrijs</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>White</source>
        <translation>Wit</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Others...</source>
        <translation>Andere...</translation>
    </message>
</context>
<context>
    <name>RDocumentVariables</name>
    <message>
        <location filename="../src/core/RDocumentVariables.cpp" line="+48"/>
        <source>Current Layer ID</source>
        <translation>ID actieve laag</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drawing Unit</source>
        <translation>Tekeningseenheid</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation>Lijntypeschaal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimension Font</source>
        <translation>Bematingslettertype</translation>
    </message>
</context>
<context>
    <name>REntity</name>
    <message>
        <location filename="../src/core/REntity.cpp" line="+95"/>
        <source>Block</source>
        <translation>Blok</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="+102"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+80"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Position</source>
        <translation>Positie</translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="+75"/>
        <source>Pixel Unit</source>
        <translation>Pixeleenheid</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="+83"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+75"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-2"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Origin</source>
        <translation>Oorsprong</translation>
    </message>
    <message>
        <location line="-1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
        <location line="+10"/>
        <source>Z</source>
        <translation>Z</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layout</source>
        <translation>Layout</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Owned by Reference</source>
        <translation>Eigendom van Referentie</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>External reference</source>
        <translation>Externe referentie</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-7"/>
        <source>Referenced Block</source>
        <translation>Gerefereerde blok</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>External Reference</source>
        <translation>Externe referentie</translation>
    </message>
    <message>
        <location line="+4"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-7"/>
        <source>Scale</source>
        <translation>Schaal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angle</source>
        <translation>Hoek</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Columns</source>
        <translation>Kolommen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Rows</source>
        <translation>Rijen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Column Spacing</source>
        <translation>Kolomafstand</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Row Spacing</source>
        <translation>Rijafstand</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Attributes</source>
        <translation>Attributen</translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="-1"/>
        <location filename="../src/core/RObject.cpp" line="+70"/>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Layer</source>
        <translation>Laag</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+104"/>
        <source>Linetype</source>
        <translation>Lijntype</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation>Lijntypeschaal</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+1"/>
        <source>Lineweight</source>
        <translation>Lijndikte</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="-2"/>
        <source>Color</source>
        <translation>Kleur</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Displayed Color</source>
        <translation>Getoonde kleur</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Draw Order</source>
        <translation>Tekenvolgorde</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Parent Id</source>
        <translation>Parent Id</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Boundary</source>
        <translation>Begrenzing</translation>
    </message>
    <message>
        <location line="-3"/>
        <location filename="../src/core/RLayout.cpp" line="+3"/>
        <source>Left</source>
        <translation>Links</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Bottom</source>
        <translation>Onderkant</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Right</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Top</source>
        <translation>Bovenkant</translation>
    </message>
    <message>
        <location filename="../src/core/RObject.cpp" line="-1"/>
        <location filename="../src/core/RPropertyTypeId.cpp" line="+162"/>
        <source>Custom</source>
        <translation>Gebruikergedefinieerd</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Handle</source>
        <translation>Handle</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Protected</source>
        <translation>Beschermd</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Selected</source>
        <translation>Geselecteerd</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Object Invisible</source>
        <translation>Object onzichtbaar</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Working Set</source>
        <translation>Werkset</translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="+2"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-2"/>
        <source>Width</source>
        <translation>Breedte</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1"/>
        <source>Size</source>
        <translation>Grootte</translation>
    </message>
    <message>
        <location line="+0"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+1"/>
        <source>Height</source>
        <translation>Hoogte</translation>
    </message>
    <message>
        <location filename="../src/core/RTextBasedEntity.cpp" line="-3"/>
        <source>Simple</source>
        <translation>Eenvoudig</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Text Position</source>
        <translation>Tekstpositie</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plain Text</source>
        <translation>Platte tekst</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Font Name</source>
        <translation>Lettertype</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Height</source>
        <translation>Teksthoogte</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Width</source>
        <translation>Tekstbreedte</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Angle</source>
        <translation>Teksthoek</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>X Scale</source>
        <translation>X schaal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bold</source>
        <translation>Vetgedrukt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Italic</source>
        <translation>Cursief</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Line Spacing</source>
        <translation>Regelafstand</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>Alignment</source>
        <translation>Uitlijning</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Horizontal</source>
        <translation>Horizontaal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Vertical</source>
        <translation>Vertikaal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Backward</source>
        <translation>Achteruit</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Upside Down</source>
        <translation>Ondersteboven</translation>
    </message>
    <message>
        <location filename="../src/core/RViewportEntity.cpp" line="+2"/>
        <source>Rotation</source>
        <translation>Rotatie</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>On</source>
        <translation>Aan</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Center</source>
        <translation>Centrum van aanzicht</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Target</source>
        <translation>Doelpunt van aanzicht</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Overall</source>
        <translation>Overall</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Frozen Layers</source>
        <translation>Bevroren lagen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Layer ID</source>
        <translation>Laag ID</translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="-8"/>
        <location filename="../src/core/RLayer.cpp" line="-8"/>
        <location filename="../src/core/RLayerState.cpp" line="+46"/>
        <location filename="../src/core/RLayout.cpp" line="-24"/>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hidden</source>
        <translation>Verborgen</translation>
    </message>
    <message>
        <location filename="../src/core/RLayer.cpp" line="+1"/>
        <source>Off</source>
        <translation>Uit</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Frozen</source>
        <translation>Bevroren</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Locked</source>
        <translation>Vergrendeld</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Collapsed</source>
        <translation>Gevouwen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plottable</source>
        <translation>Plotbaar</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Snappable</source>
        <translation>Vangbaar</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Off is Freeze</source>
        <translation>Uit is bevriezen</translation>
    </message>
    <message>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Tab Order</source>
        <translation>Tabvolgorde</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Limits</source>
        <translation>Min limieten</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Limits</source>
        <translation>Max limieten</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Insertion Base</source>
        <translation>Basis van invoeging</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Extents</source>
        <translation>Min afmetingen</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Extents</source>
        <translation>Max afmetingen</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceData.cpp" line="+920"/>
        <source>Circular (recursive) block referencing detected:</source>
        <translation>Circulaire (recursieve) blokreferenties gedetecteerd:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block name:</source>
        <translation>Bloknaam:</translation>
    </message>
    <message>
        <location filename="../src/core/RDimStyle.cpp" line="+71"/>
        <source>Style</source>
        <translation>Stijl</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Linear measurement factor</source>
        <translation>Lineaire meetfactor</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text height</source>
        <translation>Hoogte van de tekst</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimension line gap</source>
        <translation>Maat lijn uitsparing</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow size</source>
        <translation>Pijlgrootte</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimension line increment</source>
        <translation>Dimensie lijn toename</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Extension line extension</source>
        <translation>Hulplijn extentie</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Extension line offset</source>
        <translation>Extensielijnafzet</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text position vertical</source>
        <translation>Tekstpositie verticaal</translation>
    </message>
    <message>
        <location line="-8"/>
        <source>Overall scale</source>
        <translation>Algemene schaal</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Text horizontal</source>
        <translation>Tekst horizontaal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Tick size</source>
        <translation>Tikgrootte</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linear format</source>
        <translation>Lineair formaat</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal places</source>
        <translation>Decimalplaatsen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal separator</source>
        <translation>Decimaalscheidingsteken</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Zero suppression</source>
        <translation>Nul onderdrukking</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angular format</source>
        <translation>Hoekformaat</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angular decimal places</source>
        <translation>Hoek decimale plaatsen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angular zero suppression</source>
        <translation>Onderdrukking van nul hoekmaat</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Architectur tick</source>
        <translation>Architecturale markering</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text color</source>
        <translation>Tekst kleur</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow block</source>
        <translation>Pijlblok</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow block 1</source>
        <translation>Pijlblok 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow block 2</source>
        <translation>Pijlblok 2</translation>
    </message>
</context>
<context>
    <name>RGuiAction</name>
    <message>
        <location filename="../src/core/RGuiAction.cpp" line="+203"/>
        <source>Requires selection</source>
        <translation>Selectie vereist</translation>
    </message>
</context>
<context>
    <name>RLinetype</name>
    <message>
        <location filename="../src/core/RLinetype.cpp" line="+51"/>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Description</source>
        <translation>Beschrijving</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Metric</source>
        <translation>Metrisch</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pattern</source>
        <translation>Patroon</translation>
    </message>
</context>
<context>
    <name>RLinetypePattern</name>
    <message>
        <location filename="../src/core/RLinetypePattern.cpp" line="+912"/>
        <source>By Layer</source>
        <translation>Door laag bepaald</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>Door blok bepaald</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Continuous</source>
        <translation>Doorlopend</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Border</source>
        <translation>Rand</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Center</source>
        <translation>Middellijn</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dash dot</source>
        <translation>Streep punt</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dashed</source>
        <translation>Streep</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Divide</source>
        <translation>Gescheiden</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dot</source>
        <translation>Punt</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Hidden</source>
        <translation>Verborgen</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Phantom</source>
        <translation>Phantom</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>ISO dash</source>
        <translation>ISO streep</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash space</source>
        <translation>ISO streep met afstand</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash dot</source>
        <translation>ISO lange streep punt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-dot</source>
        <translation>ISO lange streep dubbele punt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash triple-dot</source>
        <translation>ISO lange streep drievoudige punt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dot</source>
        <translation>ISO punt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash short-dash</source>
        <translation>ISO lang kort streep</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-short-dash</source>
        <translation>ISO lang kort kort streep</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash dot</source>
        <translation>ISO streep punt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash dot</source>
        <translation>ISO dubbele streep, punt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash double-dot</source>
        <translation>ISO streep, dubbele punt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash double-dot</source>
        <translation>ISO dubbele streep, dubbele punt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash triple-dot</source>
        <translation>ISO streep, drievoudige punt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash triple-dot</source>
        <translation>ISO dubbele streep, drievoudige punt</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Hot Water Supply</source>
        <translation>Heet water</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hot Water</source>
        <translation>Heet water</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gas Line</source>
        <translation>Gasleiding</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Batting</source>
        <translation>Isolatie</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Zig Zag</source>
        <translation>Zigzag</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Tracks</source>
        <translation>Spoorweg</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 1</source>
        <translation>Grens rond</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 2</source>
        <translation>Grens vierkant</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Point 1</source>
        <translation>Punt 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Point 2</source>
        <translation>Punt 2</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plant</source>
        <translation>Installatie</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Water</source>
        <translation>Water</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drainage</source>
        <translation>Riolering</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drainage Reversed</source>
        <translation>Riolering omgekeerd</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Communication</source>
        <translation>Communicatie</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Electric</source>
        <translation>Elektrische</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Low Voltage</source>
        <translation>Laagspanning</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>High Voltage</source>
        <translation>Hoogspanning</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Overhead Power</source>
        <translation>Bovenleiding</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Foul</source>
        <translation>Onrein</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Foul Rising</source>
        <translation>Onzuiver stijgend</translation>
    </message>
</context>
<context>
    <name>RLineweight</name>
    <message>
        <location filename="../src/core/RLineweight.cpp" line="+37"/>
        <source>By Layer</source>
        <translation>Door laag bepaald</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>Door blok bepaald</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Default</source>
        <translation>Standaard</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.00mm</source>
        <translation>0.00mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.05mm</source>
        <translation>0.05mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.09mm</source>
        <translation>0.09mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.13mm (ISO)</source>
        <translation>0.13mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.15mm</source>
        <translation>0.15mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.18mm (ISO)</source>
        <translation>0.18mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.20mm</source>
        <translation>0.20mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.25mm (ISO)</source>
        <translation>0.25mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.30mm</source>
        <translation>0.30mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.35mm (ISO)</source>
        <translation>0.35mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.40mm</source>
        <translation>0.40mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.50mm (ISO)</source>
        <translation>0.50mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.53mm</source>
        <translation>0.53mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.60mm</source>
        <translation>0.60mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.70mm (ISO)</source>
        <translation>0.70mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.80mm</source>
        <translation>0.80mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.90mm</source>
        <translation>0.90mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.00mm (ISO)</source>
        <translation>1.00mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.06mm</source>
        <translation>1.06mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.20mm</source>
        <translation>1.20mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.40mm (ISO)</source>
        <translation>1.40mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.58mm</source>
        <translation>1.58mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.00mm (ISO)</source>
        <translation>2.00mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.11mm</source>
        <translation>2.11mm</translation>
    </message>
</context>
</TS>
